@@ -1,7 +1,7 @@
-package Module::Faker 0.025;
+package Module::Faker 0.026;
 # ABSTRACT: build fake dists for testing CPAN tools
 
-use 5.008;
+use v5.20.0;
 use Moose 0.33;
 
 use Module::Faker::Dist;
@@ -170,7 +170,7 @@ Module::Faker - build fake dists for testing CPAN tools
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
@@ -190,14 +190,15 @@ rather than a single distribution, for which see L<CPAN::Faker|CPAN::Faker>.
 =head1 PERL VERSION
 
 This module should work on any version of perl still receiving updates from
-the Perl 5 Porters.  This means it should work on any version of perl released
-in the last two to three years.  (That is, if the most recently released
-version is v5.40, then this module should work on both v5.40 and v5.38.)
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 METHODS
 
@@ -338,10 +339,6 @@ Randy Stauner <randy@magnificent-tears.com>
 
 Ricardo Signes <rjbs@semiotic.systems>
 
-=item *
-
-Ricardo Signes <rjbs@users.noreply.github.com>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
