@@ -1,6 +1,7 @@
-package Module::Faker::File 0.025;
+package Module::Faker::File 0.026;
 # ABSTRACT: a fake file in a fake dist
 
+use v5.20.0;
 use Moose;
 with 'Module::Faker::Appendix';
 
@@ -24,19 +25,20 @@ Module::Faker::File - a fake file in a fake dist
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 PERL VERSION
 
 This module should work on any version of perl still receiving updates from
-the Perl 5 Porters.  This means it should work on any version of perl released
-in the last two to three years.  (That is, if the most recently released
-version is v5.40, then this module should work on both v5.40 and v5.38.)
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 AUTHOR
 
